@@ -2,12 +2,12 @@ import dateutil.parser
 
 from datetime import date, datetime
 
-from tzlocal import get_localzone
+from tzlocal import get_localzone_name
 
 from gcsa.event import Event
+from .base_serializer import BaseSerializer
 from .attachment_serializer import AttachmentSerializer
 from .attendee_serializer import AttendeeSerializer
-from .base_serializer import BaseSerializer
 from .conference_serializer import ConferenceSolutionSerializer, ConferenceSolutionCreateRequestSerializer
 from .person_serializer import PersonSerializer
 from .reminder_serializer import ReminderSerializer
@@ -88,7 +88,7 @@ class EventSerializer(BaseSerializer):
                 start = EventSerializer._get_datetime_from_string(start_data['date']).date()
             else:
                 start = EventSerializer._get_datetime_from_string(start_data['dateTime'])
-            timezone = start_data.get('timeZone', str(get_localzone()))
+            timezone = start_data.get('timeZone', get_localzone_name())
 
         end = None
         end_data = json_event.pop('end', None)
